import React, { useState, useEffect, useRef, useCallback } from 'react';
import Button from '@s-ui/react-atom-button';
import cx from 'classnames';
import PropTypes from 'prop-types';
var BASE_CLASS = 'sui-MoleculeSelectPopover';
var SIZES = {
  MEDIUM: 'm',
  SMALL: 's',
  XSMALL: 'xs'
};

function MoleculeSelectPopover(_ref) {
  var acceptButtonText = _ref.acceptButtonText,
      cancelButtonText = _ref.cancelButtonText,
      children = _ref.children,
      IconArrowDown = _ref.iconArrowDown,
      _ref$isSelected = _ref.isSelected,
      isSelected = _ref$isSelected === void 0 ? false : _ref$isSelected,
      _ref$onAccept = _ref.onAccept,
      onAccept = _ref$onAccept === void 0 ? function () {} : _ref$onAccept,
      _ref$onCancel = _ref.onCancel,
      onCancel = _ref$onCancel === void 0 ? function () {} : _ref$onCancel,
      selectText = _ref.selectText,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? 'm' : _ref$size;

  var _useState = useState(false),
      isOpen = _useState[0],
      setIsOpen = _useState[1];

  var selectRef = useRef();
  var popoverRef = useRef();
  var selectClassName = cx(BASE_CLASS + "-select", BASE_CLASS + "-select--" + size, {
    'is-open': isOpen,
    'is-selected': isSelected
  });

  var handleOnAccept = function handleOnAccept() {
    setIsOpen(false);
    onAccept();
  };

  var handleOnCancel = useCallback(function () {
    setIsOpen(false);
    onCancel();
  }, [onCancel]);
  useEffect(function () {
    var handleClickOutside = function handleClickOutside(e) {
      if (isOpen && !popoverRef.current.contains(e.target) && !selectRef.current.contains(e.target)) {
        handleOnCancel();
      }
    };

    window.addEventListener('mousedown', handleClickOutside);
    return function () {
      window.removeEventListener('mousedown', handleClickOutside);
    };
  }, [handleOnCancel, isOpen]);
  return React.createElement("div", {
    className: BASE_CLASS
  }, React.createElement("div", {
    ref: selectRef,
    className: selectClassName,
    onClick: function onClick() {
      return setIsOpen(!isOpen);
    }
  }, React.createElement("span", {
    className: BASE_CLASS + "-selectText"
  }, selectText), React.createElement("div", {
    className: BASE_CLASS + "-selectIcon"
  }, React.createElement(IconArrowDown, null))), isOpen && React.createElement("div", {
    className: BASE_CLASS + "-popover",
    ref: popoverRef
  }, React.createElement("div", {
    className: BASE_CLASS + "-popoverContent"
  }, children), React.createElement("div", {
    className: BASE_CLASS + "-popoverActionBar"
  }, React.createElement(Button, {
    onClick: handleOnCancel,
    design: "flat"
  }, cancelButtonText), React.createElement(Button, {
    onClick: handleOnAccept
  }, acceptButtonText))));
}

MoleculeSelectPopover.displayName = 'MoleculeSelectPopover';
export default MoleculeSelectPopover;
export { SIZES as selectPopoverSizes };